ServiceLine

Enum ServiceLine 

pub enum ServiceLine {
    Boarding,
    Daycare,
    Grooming,
    Training,
    Retail,
}
Core pet-resort service line used to partition demand, capacity, and labor metrics.

Variants



Boarding

Overnight stay service line.



Daycare

Daycare operations signal for labor, capacity, or task planning.



Grooming

Grooming service line or care-note category.



Training

Training service line or care-note category.



Retail

Retail operations signal for labor, capacity, or task planning.