pub struct ServiceContractsBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> ServiceContractsBuilder<S>
impl<S: State> ServiceContractsBuilder<S>
Sourcepub fn build(self) -> ServiceContractswhere
S: IsComplete,
pub fn build(self) -> ServiceContractswhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn location_id(
self,
value: LocationId,
) -> ServiceContractsBuilder<SetLocationId<S>>where
S::LocationId: IsUnset,
pub fn location_id(
self,
value: LocationId,
) -> ServiceContractsBuilder<SetLocationId<S>>where
S::LocationId: IsUnset,
Required.
Location whose service contracts and outcomes are being compared in local or regional reports.
Sourcepub fn boarding(
self,
value: Contract,
) -> ServiceContractsBuilder<SetBoarding<S>>where
S::Boarding: IsUnset,
pub fn boarding(
self,
value: Contract,
) -> ServiceContractsBuilder<SetBoarding<S>>where
S::Boarding: IsUnset,
Required.
Boarding contract that owns stay, suite, minimum-stay, and checkout-exception rules.
Sourcepub fn daycare(self, value: Contract) -> ServiceContractsBuilder<SetDaycare<S>>where
S::Daycare: IsUnset,
pub fn daycare(self, value: Contract) -> ServiceContractsBuilder<SetDaycare<S>>where
S::Daycare: IsUnset,
Required.
Daycare contract that owns group-play eligibility, package, and ratio rules.
Sourcepub fn grooming(
self,
value: Contract,
) -> ServiceContractsBuilder<SetGrooming<S>>where
S::Grooming: IsUnset,
pub fn grooming(
self,
value: Contract,
) -> ServiceContractsBuilder<SetGrooming<S>>where
S::Grooming: IsUnset,
Required.
Grooming contract that owns service duration, rebooking cadence, add-on, and no-show rules.
Sourcepub fn training(
self,
value: Contract,
) -> ServiceContractsBuilder<SetTraining<S>>where
S::Training: IsUnset,
pub fn training(
self,
value: Contract,
) -> ServiceContractsBuilder<SetTraining<S>>where
S::Training: IsUnset,
Required.
Training contract that owns program progress, package, graduation, and trainer handoff rules.
Sourcepub fn retail(self, value: Contract) -> ServiceContractsBuilder<SetRetail<S>>where
S::Retail: IsUnset,
pub fn retail(self, value: Contract) -> ServiceContractsBuilder<SetRetail<S>>where
S::Retail: IsUnset,
Required.
Retail contract that owns catalog, inventory, POS, recommendation, and reorder gates.